
/*********************************************************************
This is an example for our Monochrome OLEDs based on SSD1306 drivers

  Pick one up today in the adafruit shop!
  ------> http://www.adafruit.com/category/63_98

This example is for a 128x64 size display using SPI to communicate
4 or 5 pins are required to interface

Adafruit invests time and resources providing this open source code,
please support Adafruit and open-source hardware by purchasing
products from Adafruit!

Written by Limor Fried/Ladyada  for Adafruit Industries.
BSD license, check license.txt for more information
All text above, and the splash screen must be included in any redistribution
*********************************************************************/
//Created by Carmelito for Multifunctional Wireless Station project
#include "Adafruit_GFX.h"
#include "Adafruit_SSD1306.h"
#include "Adafruit_DHT.h"
#include "neopixel.h"

// Connection to OLED using SPI
#define OLED_MOSI   D0
#define OLED_CLK    D1
#define OLED_DC     D2
#define OLED_CS     D3
#define OLED_RESET  D4
Adafruit_SSD1306 display(OLED_MOSI, OLED_CLK, OLED_DC, OLED_RESET, OLED_CS);

#define DHTPIN 5    // DHT11 sensor connected to pin 5
#define DHTTYPE DHT11
#define POT A0 //potentiometer connected which will act as mode switch

// NeoPixels Set pixel COUNT, PIN and TYPE
#define PIXEL_PIN A5
#define PIXEL_COUNT 4
#define PIXEL_TYPE WS2812B

Adafruit_NeoPixel strip = Adafruit_NeoPixel(PIXEL_COUNT, PIXEL_PIN, PIXEL_TYPE);

#define NUMFLAKES 10
#define XPOS 0
#define YPOS 1
#define DELTAY 2



#if (SSD1306_LCDHEIGHT != 64)
#error("Height incorrect, please fix Adafruit_SSD1306.h!");
#endif

DHT dht(DHTPIN, DHTTYPE);
String outside ="";//variable to store the High and Low temperature outside
String weatherCond = "";//Weather condition description
String tweetCheck = "";//twitter check
String espnScore = "";//ESPN score of your faviroite team
String surfRep =""; //Check surf report from Surfline.com via IFTTT //Uncomment if your using the surf report recipe
String messageMom=""; //stores message from a web page

String neoPixelColor ="All";

void setup()   {
  Serial.begin(9600);
  pinMode(POT, INPUT);
  dht.begin();
  strip.begin();
  strip.show(); // Initialize all NeoPixelspixels to 'off
  // by default, we'll generate the high voltage from the 3.3v line internally! (neat!)
  display.begin(SSD1306_SWITCHCAPVCC);
  //this shows the Adafruit splashscreen
  display.display(); // show splashscreen
  delay(2000);
  display.clearDisplay();   // clears the screen and buffer

//Spark functions invoked by the IFTTT recipe
 Spark.function("SetWeather", SetWeather);
 Spark.function("WeatherCond", WeatherCond);
 Spark.function("TweetCheck", TweetCheck);
 //Commenting this as there is a limimation that you can have only 4 spark functions at a given time
//Spark.function("SurfReport", SurfReport);
 //Spark.function("EspnScore", EspnScore);
//Reciving a message from a web page
 Spark.function("MessageMom", MessageMom);

}


void loop() {
  int potValue = analogRead(POT);

  //Posting the Pot value to the screen for testing so that you can get an idea of the ranges
 //COMMENT OUT THIS SECTION ONCE YOU DECIDE ON THE VALUES FOR YOUR DIAL aka the POT
  /*display.setCursor(0,0);
  display.setTextSize(2);
  display.setTextColor(WHITE);
  display.println("Pot Value:" +String(potValue));
  display.display();
  delay(2000);
  display.clearDisplay();*/
  if(neoPixelColor == "All")
  {
  rainbow(5);
  }else if (neoPixelColor == "Red"){
  neopixelRed();
  }else if (neoPixelColor == "Green"){
    neopixelGreen();
  }else if (neoPixelColor == "Blue"){
    neopixelBlue();
  }else{
    neopixelOff();
  }

  if(potValue > 4000)
  {
    // draw scrolling text - display your fav quote/message
    testscrolltext();
    delay(5);
    display.clearDisplay();
    //rainbow(50);//Enable to test the neopixels
    //reset NeoPixels
    neoPixelColor ="Off";
    //reset message from the HTML page
    messageMom="";
    tweetCheck = "";

  }else if (potValue >3000 && potValue < 4000){
    // Reading temperature and humidity to diplay on the OLED screen
    	float h = dht.getHumidity();
    // Read temperature as Celsius
    	float t = dht.getTempCelcius();
    // Check if any reads failed and exit early (to try again).
    	if (isnan(h) || isnan(t)) {
    		Serial.println("err ... \n Failed to read \n from DHT sensor!");
    		return;
    	}
      if(int(t) > 25){
        neoPixelColor="Red";
      }
      // text display Temperature and Humidity inside your home
      display.setTextSize(1);
      display.setTextColor(WHITE);
      display.setCursor(0,0);
      display.println("Inside"); //Time.timeStr()
      display.setTextSize(2);
      display.setTextColor(WHITE);
      display.println("Temp :" +String(int(t))+"C\n");
      display.setTextSize(2);
      display.setTextColor(WHITE);
      display.println("Humid:"+ String(int(h)) +"%");
      display.display();
      delay(2000);
      display.clearDisplay();


 }else if (potValue >2000 && potValue < 3000){
   // Display temperature HIGH and LOW, outside using a recipe on IFTTT
   if (outside.length() > 0)
   {
     display.setTextSize(1);
     display.setCursor(10,0);
     display.setTextColor(WHITE);
     display.println("Outside");
     display.setTextSize(2);
     display.setTextColor(WHITE);
     display.println(outside);
     display.display();
     delay(2000);
     display.clearDisplay();
   }else{
     display.setTextSize(1);
     display.setCursor(10,0);
     display.setTextColor(WHITE);
     display.println("err....\n Outside Weather \n not avaliable..");
     display.display();
     delay(2000);
     display.clearDisplay();
   }
 }else if (potValue >1000 && potValue < 2000){
   // Display Weather Condition using a recipe on IFTTT
   if (weatherCond.length() > 0)
   {
     display.setTextSize(2);
     display.setCursor(10,0);
     display.setTextColor(WHITE);
     display.println(weatherCond);
     display.display();
     delay(2000);
     display.clearDisplay();
   }else{
     display.setTextSize(1);
     display.setCursor(10,0);
     display.setTextColor(WHITE);
     display.println("err....\nWeather Condition \n not avaliable..");
     display.display();
     delay(2000);
     display.clearDisplay();
   }
 }else if (potValue >200 && potValue < 1000)
 { //Display the ESPN score of your fav team
  //OR display the surf report if the fair-good , Condition mentioned in IFTTT recipe
  if (surfRep.length() > 0)
  {
    display.setTextSize(1);
    display.setCursor(10,0);
    display.setTextColor(WHITE);
    display.println(espnScore); // replace with - surfRep
    display.display();
    delay(2000);
    display.clearDisplay();
  }else{
    display.setTextSize(1);
    display.setCursor(10,0);
    display.setTextColor(WHITE);
    display.println("ESPN score not avaliable"); // replace with "No Surf report \n check surfline.com.."
    display.display();
    delay(2000);
    display.clearDisplay();
  }
 }else{
   // Display tweet in which your mentioned-  @{{UserName}} : {{Text}}
   if (tweetCheck.length() > 0)
   {
     display.setTextSize(1);
     display.setCursor(10,0);
     display.setTextColor(WHITE);
     display.println(tweetCheck);
     display.display();
     delay(2000);
     display.clearDisplay();
     neoPixelColor="Blue";
   }else{
     display.setTextSize(1);
     display.setCursor(10,0);
     display.setTextColor(WHITE);
     display.println("No tweets that you have been mentioned in ...");
     display.display();
     neoPixelColor="Blue";
     delay(2000);

     display.clearDisplay();
   }
 }

//Display message from MOM sent from the HTML page
if (messageMom.length() > 0)
  {
    display.setTextSize(2);
    display.setCursor(10,0);
    display.setTextColor(WHITE);
    display.println(messageMom);
    display.display();
    rainbow(10);//run a rainbow color
    delay(1000);
    display.clearDisplay();
    neoPixelColor="All";
  }
}//end of loop

//Spark functions
int SetWeather(String message) {
  outside = message ;
}

int WeatherCond(String message) {
  weatherCond = message;
}

int TweetCheck(String message) {
  tweetCheck = message;
}

int EspnScore(String message) {
  espnScore = message;
}
/*int SurfReport(String message) {
  surfRep = message;
}*/ //Uncomment if you plan to use the surfline recipe
int MessageMom(String message) {
  messageMom = message;
}

void testscrolltext(void) {
  display.setTextSize(2);
  display.setCursor(10,0);
  display.setTextColor(WHITE);
  display.println("  IoT  ");
  display.setTextSize(1);
  display.setTextColor(WHITE);
  display.println("\n Particle Photon \n and IFTTT.com..");
  display.display();
  delay(500);
  display.clearDisplay();

  display.startscrollright(0x00, 0x0F);
  delay(300);
  display.stopscroll();
  delay(100);
  display.startscrollleft(0x00, 0x0F);
  delay(100);
  display.stopscroll();

}
void rainbow(uint8_t wait) {
  uint16_t i, j;

  for(j=0; j<256; j++) {
    for(i=0; i<strip.numPixels(); i++) {
      strip.setPixelColor(i, Wheel((i+j) & 255));
    }
    strip.show();
    delay(wait);
  }
}

// Input a value 0 to 255 to get a color value.
// The colours are a transition r - g - b - back to r.
uint32_t Wheel(byte WheelPos) {
  if(WheelPos < 85) {
   return strip.Color(WheelPos * 3, 255 - WheelPos * 3, 0);
  } else if(WheelPos < 170) {
   WheelPos -= 85;
   return strip.Color(255 - WheelPos * 3, 0, WheelPos * 3);
  } else {
   WheelPos -= 170;
   return strip.Color(0, WheelPos * 3, 255 - WheelPos * 3);
  }
}
void neopixelOff(){
  uint16_t i;
  for(i=0; i<strip.numPixels(); i++) {
  strip.setPixelColor(i, strip.Color(0, 0, 0)); //all Pixels off
  delay(500);
  strip.show();
  }
}
void neopixelBlue(){
  uint16_t i;
  for(i=0; i<strip.numPixels(); i++) {
  strip.setPixelColor(i, strip.Color(0, 0, 255)); //all Blue
  delay(500);
  strip.show();
  }
}
void neopixelGreen(){
  uint16_t i;
  for(i=0; i<strip.numPixels(); i++) {
  strip.setPixelColor(i, strip.Color(0, 255, 0)); //all Green
  delay(500);
  strip.show();
  }
}
void neopixelRed(){
    uint16_t i;
    for(i=0; i<strip.numPixels(); i++) {
    strip.setPixelColor(i, strip.Color(255, 0, 0)); //all Green
    delay(500);
    strip.show();
    }
}
